installations: [xonsh] apt update -y [xonsh] apt upgrade [xonsh] apt install sudo rethinkdb: # # # [xonsh] apt install wget -y [xonsh] apt install gpg -y [xonsh] apt-get update && apt-get install -y lsb-release && apt-get clean all wget -qO- https://download.rethinkdb.com/repository/raw/pubkey.gpg | gpg --dearmor -o /usr/share/keyrings/rethinkdb-archive-keyrings.gpg echo "deb [signed-by=/usr/share/keyrings/rethinkdb-archive-keyrings.gpg] https://download.rethinkdb.com/repository/ubuntu-$(lsb_release -cs) $(lsb_release -cs) main" | tee /etc/apt/sources.list.d/rethinkdb.list apt update apt install rethinkdb -y rethinkdb --version mongodb: # # https://www.mongodb.com/docs/manual/tutorial/install-mongodb-on-ubuntu/ # apt install gnupg curl -y curl -fsSL https://www.mongodb.org/static/pgp/server-7.0.asc | \ sudo gpg -o /usr/share/keyrings/mongodb-server-7.0.gpg \ --dearmor echo "deb [ arch=amd64,arm64 signed-by=/usr/share/keyrings/mongodb-server-7.0.gpg ] https://repo.mongodb.org/apt/ubuntu jammy/mongodb-org/7.0 multiverse" | sudo tee /etc/apt/sources.list.d/mongodb-org-7.0.list apt update apt-get install -y mongodb-org python3: # already installed pip: # # https://pip.pypa.io/en/stable/installation/ # sudo apt install python3-pip